parallax package
================

Submodules
----------

parallax.calibration\_camera module
-----------------------------------

.. automodule:: parallax.calibration_camera
   :members:
   :undoc-members:
   :show-inheritance:

parallax.camera module
----------------------

.. automodule:: parallax.camera
   :members:
   :undoc-members:
   :show-inheritance:

parallax.curr\_bg\_cmp\_processor module
----------------------------------------

.. automodule:: parallax.curr_bg_cmp_processor
   :members:
   :undoc-members:
   :show-inheritance:

parallax.curr\_prev\_cmp\_processor module
------------------------------------------

.. automodule:: parallax.curr_prev_cmp_processor
   :members:
   :undoc-members:
   :show-inheritance:

parallax.main\_window\_wip module
---------------------------------

.. automodule:: parallax.main_window_wip
   :members:
   :undoc-members:
   :show-inheritance:

parallax.mask\_generator module
-------------------------------

.. automodule:: parallax.mask_generator
   :members:
   :undoc-members:
   :show-inheritance:

parallax.model module
---------------------

.. automodule:: parallax.model
   :members:
   :undoc-members:
   :show-inheritance:

parallax.no\_filter module
--------------------------

.. automodule:: parallax.no_filter
   :members:
   :undoc-members:
   :show-inheritance:

parallax.probe\_calibration module
----------------------------------

.. automodule:: parallax.probe_calibration
   :members:
   :undoc-members:
   :show-inheritance:

parallax.probe\_detect\_manager module
--------------------------------------

.. automodule:: parallax.probe_detect_manager
   :members:
   :undoc-members:
   :show-inheritance:

parallax.probe\_detector module
-------------------------------

.. automodule:: parallax.probe_detector
   :members:
   :undoc-members:
   :show-inheritance:

parallax.probe\_fine\_tip\_detector module
------------------------------------------

.. automodule:: parallax.probe_fine_tip_detector
   :members:
   :undoc-members:
   :show-inheritance:

parallax.recording\_manager module
----------------------------------

.. automodule:: parallax.recording_manager
   :members:
   :undoc-members:
   :show-inheritance:

parallax.reticle\_detect\_manager module
----------------------------------------

.. automodule:: parallax.reticle_detect_manager
   :members:
   :undoc-members:
   :show-inheritance:

parallax.reticle\_detection module
----------------------------------

.. automodule:: parallax.reticle_detection
   :members:
   :undoc-members:
   :show-inheritance:

parallax.reticle\_detection\_coords\_interests module
-----------------------------------------------------

.. automodule:: parallax.reticle_detection_coords_interests
   :members:
   :undoc-members:
   :show-inheritance:

parallax.screen\_widget module
------------------------------

.. automodule:: parallax.screen_widget
   :members:
   :undoc-members:
   :show-inheritance:

parallax.stage\_listener module
-------------------------------

.. automodule:: parallax.stage_listener
   :members:
   :undoc-members:
   :show-inheritance:

parallax.stage\_ui module
-------------------------

.. automodule:: parallax.stage_ui
   :members:
   :undoc-members:
   :show-inheritance:

parallax.stage\_widget module
-----------------------------

.. automodule:: parallax.stage_widget
   :members:
   :undoc-members:
   :show-inheritance:

parallax.utils module
---------------------

.. automodule:: parallax.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: parallax
   :members:
   :undoc-members:
   :show-inheritance:
